@@ -4,7 +4,7 @@
  * Created Date: 28/05/2021
  * Author: Shun Suzuki
  * -----
- * Last Modified: 18/06/2021
+ * Last Modified: 21/07/2021
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
  * Copyright (c) 2021 Hapis Lab. All rights reserved.
@@ -19,5 +19,5 @@ pub use autd3_core::{
         AUTD_HEIGHT, AUTD_WIDTH, NUM_TRANS_IN_UNIT, NUM_TRANS_X, NUM_TRANS_Y, TRANS_SPACING_MM,
     },
     link::Link,
-    sequence::PointSequence,
+    sequence::{GainSequence, PointSequence, Sequence},
 };
